@@ -1,6 +1,6 @@
 /* $Author: schaid $ */
-/* $Date: 2005/03/01 23:06:04 $ */
-/* $Header: /people/biostat3/sinnwell/Rdir/Make/RCS/haplo_em_pin.h,v 1.6 2005/03/01 23:06:04 schaid Exp $ */
+/* $Date: 2007/02/27 20:18:01 $ */
+/* $Header: /people/biostat3/sinnwell/Haplo/Make/RCS/haplo_em_pin.h,v 1.7 2007/02/27 20:18:01 schaid Exp $ */
 /* $Locker:  $ */
 
 /*
@@ -37,24 +37,20 @@
 
 
 
-/* redefine long to be int to be compatible with R */
-
-#define long int
-
 typedef struct HAP_T {
-  long id;
-  long code;
-  long pair_id;
-  long keep;
-  long *loci;
+  int id;
+  int code;
+  int pair_id;
+  int keep;
+  int *loci;
   double post, wt;
 } HAP;
 
 
 typedef struct HAPUNIQUE_T {
-  long code;
-  long keep;
-  long *loci;
+  int code;
+  int keep;
+  int *loci;
   double prior;
 } HAPUNIQUE;
 
@@ -74,9 +70,9 @@ static int iminarg1, iminarg2;
 
 /************************** Function prototypes ***********************************/
 
-static HAP* new_hap(long id, long pair_id, double wt, double prior, double post);
+static HAP* new_hap(int id, int pair_id, double wt, double prior, double post);
 
-static void write_hap_list(HAP** so, long n_hap);
+static void write_hap_list(HAP** so, int n_hap);
 
 
 static int CDECL cmp_hap(const void *to_one, const void *to_two);
@@ -85,26 +81,26 @@ static int CDECL cmp_subId_hapPairId(const void *to_one, const void *to_two);
 
 static int CDECL cmp_hap_code(const void *to_one, const void *to_two);
 
-static long code_haps(long n_hap, HAP **hap_list);
+static int code_haps(int n_hap, HAP **hap_list);
 
-static long hap_enum(HAP ***hap_list_ptr, double **prior_ptr, long *max_haps, long *n_alleles, long insert_loc, 
-		     long n_hap, long *pair_id);
+static int hap_enum(HAP ***hap_list_ptr, double **prior_ptr, int *max_haps, int *n_alleles, int insert_loc, 
+		     int n_hap, int *pair_id);
 
 static HAP* copy_hap(HAP *old);
 
-static long num_het(HAP* h1,HAP* h2);
+static int num_het(HAP* h1,HAP* h2);
 
-static void hap_prior(long n_hap, HAP** hap_list, double *prior, long n_u_hap,
+static void hap_prior(int n_hap, HAP** hap_list, double *prior, int n_u_hap,
                       double min_prior);
 
-static long hap_posterior(long n_hap, HAP **hap_list, double *prior, 
-			  long n_u_hap, double min_posterior, double *lnlike);
+static int hap_posterior(int n_hap, HAP **hap_list, double *prior, 
+			  int n_u_hap, double min_posterior, double *lnlike);
 
-static long **long_vec_to_mat(long *Yvec, long nrow, long ncol);
+static int **int_vec_to_mat(int *Yvec, int nrow, int ncol);
 
-static long **long_matrix(long nrow, long ncol);
+static int **int_matrix(int nrow, int ncol);
 
-static void set_posterior(long n_hap, HAP **hap_list, long *random_start);
+static void set_posterior(int n_hap, HAP **hap_list, int *random_start);
 
 static int ranAS183_seed(int iseed1, int iseed2, int iseed3);
 
@@ -112,26 +108,28 @@ static double ranAS183();
 
 static void errmsg(char *string);
 
-static void compact(HAP **hap_list, long n, long *nReturn);
+static void compact(HAP **hap_list, int n, int *nReturn);
 
 static HAPUNIQUE* copy_hap_unique(HAP *old, double *prior);
 
-static void unique_haps(long n_hap, HAP **hap_list, HAPUNIQUE **u_hap_list, double *prior);
+static void unique_haps(int n_hap, HAP **hap_list, HAPUNIQUE **u_hap_list, double *prior);
 
-static long count_unique_haps(long n_hap, HAP **hap_list);
+static int count_unique_haps(int n_hap, HAP **hap_list);
 
-static void write_prior(long n, double *prior);
+static void write_prior(int n, double *prior);
 
-static void write_unique_hap_list(HAPUNIQUE** so, long n_hap);
+static void write_unique_hap_list(HAPUNIQUE** so, int n_hap);
 
-static void divideKeep(HAP **hap_list, long n, long *nReturn);
+static void divideKeep(HAP **hap_list, int n, int *nReturn);
 
-static void add_more_memory(HAP ***hap_list, double **prior,long *max_haps);
+static void add_more_memory(HAP ***hap_list, double **prior,int *max_haps);
 
 static void insert_new_hap_pair(HAP ***hap_list_ptr, double **prior_ptr, 
-                                long *max_haps, long insert_loc,
+                                int *max_haps, int insert_loc,
                                 HAP *h1_old, HAP *h2_old, 
-                                long a1_new, long a2_new,
-                                long *pair_id, long *j);
+                                int a1_new, int a2_new,
+                                int *pair_id, int *j);
 
 static void overwrite_hap(HAP *new, HAP *old);
+
+void checkIntMax(int *intMax);
